@@ -13,23 +13,29 @@ status_by_code = {
 #### ApiError-s
 
 class ApiError(Exception):
-
     def __init__(self, status_code, error=None):
         self.status_code = status_code
         self.error = error
 
-class Invalid(ApiError):
+class BadRequest(ApiError):
+    def __init__(self, field_name, state, explain=None):
+        super(BadRequest, self).__init__(400, '{field_name} is {state}'.format(field_name=field_name, state=state) + ('' if explain is None else ': {explain}'.format(explain=explain)))
 
-    def __init__(self, field_name, error=None):
-        super(Invalid, self).__init__(400, '{field_name} is Invalid'.format(field_name=field_name) + ('' if error is None else ': {error}'.format(error=error)))
+class Missing(BadRequest):
+    def __init__(self, field_name, explain=None):
+        super(Missing, self).__init__(field_name, 'Missing', explain)
+
+class Invalid(BadRequest):
+    def __init__(self, field_name, explain=None):
+        super(Invalid, self).__init__(field_name, 'Invalid', explain)
 
 #### field
 
-def field(request, field_name, is_required=False, default_value=None, valid_value=None, valid_type=None, valid_length=None, max_length=None):
+def field(request, field_name, is_required=False, default_value=None, valid_value=None, valid_type=None, valid_length=None, max_length=None, explain=None):
 
     if field_name not in request:
         if is_required:
-            raise ApiError(400, '{field_name} is Missing'.format(field_name=field_name))
+            raise Missing(field_name, explain)
         return default_value
 
     field_value = request[field_name]
@@ -40,6 +46,6 @@ def field(request, field_name, is_required=False, default_value=None, valid_valu
         valid_length is not None and len(field_value) != valid_length or
         max_length is not None and len(field_value) > max_length
     ):
-        raise Invalid(field_name)
+        raise Invalid(field_name, explain)
 
     return field_value
